@@ -68,10 +68,10 @@ class ClusterManagerTransport(abc.ABC):
             scope (Optional[Sequence[str]]): A list of scopes.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
-            client_info (google.api_core.gapic_v1.client_info.ClientInfo):	
-                The client info used to send a user-agent string along with	
-                API requests. If ``None``, then default info will be used.	
-                Generally, you only need to set this if you're developing	
+            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
+                The client info used to send a user-agent string along with
+                API requests. If ``None``, then default info will be used.
+                Generally, you only need to set this if you're developing
                 your own client library.
         """
         # Save the hostname. Default to port 443 (HTTPS) if none is specified.
@@ -79,6 +79,9 @@ class ClusterManagerTransport(abc.ABC):
             host += ":443"
         self._host = host
 
+        # Save the scopes.
+        self._scopes = scopes or self.AUTH_SCOPES
+
         # If no credentials are provided, then determine the appropriate
         # defaults.
         if credentials and credentials_file:
@@ -88,20 +91,17 @@ class ClusterManagerTransport(abc.ABC):
 
         if credentials_file is not None:
             credentials, _ = auth.load_credentials_from_file(
-                credentials_file, scopes=scopes, quota_project_id=quota_project_id
+                credentials_file, scopes=self._scopes, quota_project_id=quota_project_id
             )
 
         elif credentials is None:
             credentials, _ = auth.default(
-                scopes=scopes, quota_project_id=quota_project_id
+                scopes=self._scopes, quota_project_id=quota_project_id
             )
 
         # Save the credentials.
         self._credentials = credentials
 
-        # Lifted into its own function so it can be stubbed out during tests.
-        self._prep_wrapped_messages(client_info)
-
     def _prep_wrapped_messages(self, client_info):
         # Precompute the wrapped methods.
         self._wrapped_methods = {
@@ -114,6 +114,7 @@ class ClusterManagerTransport(abc.ABC):
                     predicate=retries.if_exception_type(
                         exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
+                    deadline=20.0,
                 ),
                 default_timeout=20.0,
                 client_info=client_info,
@@ -127,6 +128,7 @@ class ClusterManagerTransport(abc.ABC):
                     predicate=retries.if_exception_type(
                         exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
+                    deadline=20.0,
                 ),
                 default_timeout=20.0,
                 client_info=client_info,
@@ -174,6 +176,7 @@ class ClusterManagerTransport(abc.ABC):
                     predicate=retries.if_exception_type(
                         exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
+                    deadline=20.0,
                 ),
                 default_timeout=20.0,
                 client_info=client_info,
@@ -187,6 +190,7 @@ class ClusterManagerTransport(abc.ABC):
                     predicate=retries.if_exception_type(
                         exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
+                    deadline=20.0,
                 ),
                 default_timeout=20.0,
                 client_info=client_info,
@@ -200,6 +204,7 @@ class ClusterManagerTransport(abc.ABC):
                     predicate=retries.if_exception_type(
                         exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
+                    deadline=20.0,
                 ),
                 default_timeout=20.0,
                 client_info=client_info,
@@ -216,6 +221,7 @@ class ClusterManagerTransport(abc.ABC):
                     predicate=retries.if_exception_type(
                         exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
+                    deadline=20.0,
                 ),
                 default_timeout=20.0,
                 client_info=client_info,
@@ -229,6 +235,7 @@ class ClusterManagerTransport(abc.ABC):
                     predicate=retries.if_exception_type(
                         exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
+                    deadline=20.0,
                 ),
                 default_timeout=20.0,
                 client_info=client_info,
@@ -245,6 +252,7 @@ class ClusterManagerTransport(abc.ABC):
                     predicate=retries.if_exception_type(
                         exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
+                    deadline=20.0,
                 ),
                 default_timeout=20.0,
                 client_info=client_info,
@@ -261,6 +269,7 @@ class ClusterManagerTransport(abc.ABC):
                     predicate=retries.if_exception_type(
                         exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
+                    deadline=20.0,
                 ),
                 default_timeout=20.0,
                 client_info=client_info,
@@ -309,6 +318,7 @@ class ClusterManagerTransport(abc.ABC):
                     predicate=retries.if_exception_type(
                         exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
+                    deadline=20.0,
                 ),
                 default_timeout=20.0,
                 client_info=client_info,
@@ -322,6 +332,7 @@ class ClusterManagerTransport(abc.ABC):
                     predicate=retries.if_exception_type(
                         exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
                     ),
+                    deadline=20.0,
                 ),
                 default_timeout=20.0,
                 client_info=client_info,
